@@ -13,7 +13,7 @@ logger = logging.getLogger(__name__)
 
 
 class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
-    """
+    r"""
     If filepath_template is provided, the key to this StoreBackend abstract class must be a tuple with
     fixed length equal to the number of unique components matching the regex r"{\d+}"
 
@@ -29,6 +29,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
         forbidden_substrings=None,
         platform_specific_separator=True,
         fixed_length_key=False,
+        base_public_path=None,
     ):
         super().__init__(fixed_length_key=fixed_length_key)
         if forbidden_substrings is None:
@@ -52,6 +53,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
                 )
         self.filepath_prefix = filepath_prefix
         self.filepath_suffix = filepath_suffix
+        self.base_public_path = base_public_path
 
         if filepath_template is not None:
             # key length is the number of unique values to be substituted in the filepath_template
@@ -67,7 +69,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
             for substring in self.forbidden_substrings:
                 if substring in key_element:
                     raise ValueError(
-                        "Keys in {0} must not contain substrings in {1} : {2}".format(
+                        "Keys in {} must not contain substrings in {} : {}".format(
                             self.__class__.__name__, self.forbidden_substrings, key,
                         )
                     )
@@ -75,7 +77,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
     def _validate_value(self, value):
         if not isinstance(value, str) and not isinstance(value, bytes):
             raise TypeError(
-                "Values in {0} must be instances of {1} or {2}, not {3}".format(
+                "Values in {} must be instances of {} or {}, not {}".format(
                     self.__class__.__name__, str, bytes, type(value),
                 )
             )
@@ -138,7 +140,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
             # Convert the template to a regex
             indexed_string_substitutions = re.findall(r"{\d+}", filepath_template)
             tuple_index_list = [
-                "(?P<tuple_index_{0}>.*)".format(i,)
+                "(?P<tuple_index_{}>.*)".format(i,)
                 for i in range(len(indexed_string_substitutions))
             ]
             intermediate_filepath_regex = re.sub(
@@ -177,7 +179,7 @@ class TupleStoreBackend(StoreBackend, metaclass=ABCMeta):
         new_key = self._convert_filepath_to_key(filepath)
         if key != new_key:
             raise ValueError(
-                "filepath template {0} for class {1} is not reversible for a tuple of length {2}. "
+                "filepath template {} for class {} is not reversible for a tuple of length {}. "
                 "Have you included all elements in the key tuple?".format(
                     self.filepath_template, self.__class__.__name__, self.key_length,
                 )
@@ -202,6 +204,7 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
         platform_specific_separator=True,
         root_directory=None,
         fixed_length_key=False,
+        base_public_path=None,
     ):
         super().__init__(
             filepath_template=filepath_template,
@@ -210,6 +213,7 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
             forbidden_substrings=forbidden_substrings,
             platform_specific_separator=platform_specific_separator,
             fixed_length_key=fixed_length_key,
+            base_public_path=base_public_path,
         )
         if os.path.isabs(base_directory):
             self.full_base_directory = base_directory
@@ -220,7 +224,7 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
                 )
             elif not os.path.isabs(root_directory):
                 raise ValueError(
-                    "root_directory must be an absolute path. Got {0} instead.".format(
+                    "root_directory must be an absolute path. Got {} instead.".format(
                         root_directory
                     )
                 )
@@ -336,12 +340,23 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
     def get_url_for_key(self, key, protocol=None):
         path = self._convert_key_to_filepath(key)
         full_path = os.path.join(self.full_base_directory, path)
+
         if protocol is None:
             protocol = "file:"
         url = protocol + "//" + full_path
-
         return url
 
+    def get_public_url_for_key(self, key, protocol=None):
+        if not self.base_public_path:
+            raise StoreBackendError(
+                f"""Error: No base_public_path was configured!
+                    - A public URL was requested base_public_path was not configured for the TupleFilesystemStoreBackend
+                """
+            )
+        path = self._convert_key_to_filepath(key)
+        public_url = self.base_public_path + path
+        return public_url
+
     def _has_key(self, key):
         return os.path.isfile(
             os.path.join(self.full_base_directory, self._convert_key_to_filepath(key))
@@ -367,6 +382,7 @@ class TupleS3StoreBackend(TupleStoreBackend):
         forbidden_substrings=None,
         platform_specific_separator=False,
         fixed_length_key=False,
+        base_public_path=None,
     ):
         super().__init__(
             filepath_template=filepath_template,
@@ -375,6 +391,7 @@ class TupleS3StoreBackend(TupleStoreBackend):
             forbidden_substrings=forbidden_substrings,
             platform_specific_separator=platform_specific_separator,
             fixed_length_key=fixed_length_key,
+            base_public_path=base_public_path,
         )
         self.bucket = bucket
         if prefix:
@@ -442,7 +459,7 @@ class TupleS3StoreBackend(TupleStoreBackend):
                 )
             else:
                 result_s3.put(Body=value, ContentType=content_type)
-        except s3.exceptions.ClientError as e:
+        except s3.meta.client.exceptions.ClientError as e:
             logger.debug(str(e))
             raise StoreBackendError("Unable to set object in s3.")
 
@@ -525,14 +542,44 @@ class TupleS3StoreBackend(TupleStoreBackend):
         else:
             location = "s3-" + location
         s3_key = self._convert_key_to_filepath(key)
+
+        location = boto3.client("s3").get_bucket_location(Bucket=self.bucket)[
+            "LocationConstraint"
+        ]
+        if location is None:
+            location = "s3"
+        else:
+            location = "s3-" + location
         if not self.prefix:
-            return f"https://{location}.amazonaws.com/{self.bucket}/{s3_key}"
-        return f"https://{location}.amazonaws.com/{self.bucket}/{self.prefix}/{s3_key}"
+            url = f"https://{location}.amazonaws.com/{self.bucket}/{s3_key}"
+        else:
+            url = (
+                f"https://{location}.amazonaws.com/{self.bucket}/{self.prefix}/{s3_key}"
+            )
+        return url
+
+    def get_public_url_for_key(self, key, protocol=None):
+        if not self.base_public_path:
+            raise StoreBackendError(
+                f"""Error: No base_public_path was configured!
+                    - A public URL was requested base_public_path was not configured for the
+                """
+            )
+        s3_key = self._convert_key_to_filepath(key)
+        # <WILL> What happens if there is a prefix?
+        if self.base_public_path[-1] != "/":
+            public_url = self.base_public_path + "/" + s3_key
+        else:
+            public_url = self.base_public_path + s3_key
+        return public_url
 
     def remove_key(self, key):
         import boto3
         from botocore.exceptions import ClientError
 
+        if not isinstance(key, tuple):
+            key = key.to_tuple()
+
         s3 = boto3.resource("s3")
         s3_object_key = self._build_s3_object_key(key)
         s3.Object(self.bucket, s3_object_key).delete()
@@ -584,6 +631,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
         platform_specific_separator=False,
         fixed_length_key=False,
         public_urls=True,
+        base_public_path=None,
     ):
         super().__init__(
             filepath_template=filepath_template,
@@ -592,6 +640,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
             forbidden_substrings=forbidden_substrings,
             platform_specific_separator=platform_specific_separator,
             fixed_length_key=fixed_length_key,
+            base_public_path=base_public_path,
         )
         self.bucket = bucket
         self.prefix = prefix
@@ -677,17 +726,40 @@ class TupleGCSStoreBackend(TupleStoreBackend):
 
     def get_url_for_key(self, key, protocol=None):
         path = self._convert_key_to_filepath(key)
+
         if self._public_urls:
             base_url = "https://storage.googleapis.com/"
         else:
             base_url = "https://storage.cloud.google.com/"
 
+        path_url = self._get_path_url(path)
+
+        return base_url + path_url
+
+    def get_public_url_for_key(self, key, protocol=None):
+        if not self.base_public_path:
+            raise StoreBackendError(
+                f"""Error: No base_public_path was configured!
+                    - A public URL was requested base_public_path was not configured for the
+                """
+            )
+        path = self._convert_key_to_filepath(key)
+        path_url = self._get_path_url(path)
+        public_url = self.base_public_path + path_url
+        return public_url
+
+    def _get_path_url(self, path):
         if self.prefix:
             path_url = "/".join((self.bucket, self.prefix, path))
         else:
-            path_url = "/".join((self.bucket, path))
-
-        return base_url + path_url
+            if self.base_public_path:
+                if self.base_public_path[-1] != "/":
+                    path_url = "/" + path
+                else:
+                    path_url = path
+            else:
+                path_url = "/".join((self.bucket, path))
+        return path_url
 
     def remove_key(self, key):
         from google.cloud import storage
@@ -696,7 +768,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
         gcs = storage.Client(project=self.project)
         bucket = gcs.get_bucket(self.bucket)
         try:
-            bucket.delete_blobs(blobs=bucket.list_blobs(prefix=self.prefix))
+            bucket.delete_blobs(blobs=list(bucket.list_blobs(prefix=self.prefix)))
         except NotFound:
             return False
         return True
