@@ -2,6 +2,7 @@ import copy
 import inspect
 import json
 import logging
+import warnings
 from collections import OrderedDict
 from datetime import datetime
 from functools import reduce, wraps
@@ -21,22 +22,29 @@ from .pandas_dataset import PandasDataset
 logger = logging.getLogger(__name__)
 
 try:
-    from pyspark.sql.functions import (
-        udf,
-        col,
-        lit,
-        desc,
-        stddev_samp,
-        length as length_,
-        when,
-        year,
-        count,
-        countDistinct,
-        monotonically_increasing_id,
-    )
     import pyspark.sql.types as sparktypes
     from pyspark.ml.feature import Bucketizer
-    from pyspark.sql import Window
+    from pyspark.sql import SQLContext, Window
+    from pyspark.sql.functions import (
+        array,
+        col,
+        count,
+        countDistinct,
+        datediff,
+        desc,
+        expr,
+        isnan,
+        lag,
+    )
+    from pyspark.sql.functions import length as length_
+    from pyspark.sql.functions import (
+        lit,
+        monotonically_increasing_id,
+        stddev_samp,
+        udf,
+        when,
+        year,
+    )
 except ImportError as e:
     logger.debug(str(e))
     logger.debug(
@@ -53,7 +61,7 @@ class MetaSparkDFDataset(Dataset):
     """
 
     def __init__(self, *args, **kwargs):
-        super(MetaSparkDFDataset, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     @classmethod
     def column_map_expectation(cls, func):
@@ -72,7 +80,7 @@ class MetaSparkDFDataset(Dataset):
         @cls.expectation(argspec)
         @wraps(func)
         def inner_wrapper(
-            self, column, mostly=None, result_format=None, *args, **kwargs
+            self, column, mostly=None, result_format=None, *args, **kwargs,
         ):
             """
             This whole decorator is pending a re-write. Currently there is are huge performance issues
@@ -81,6 +89,10 @@ class MetaSparkDFDataset(Dataset):
             are done on the dataset, as is done in sqlalchemy_dataset.
             """
 
+            # Rename column so we only have to handle dot notation here
+            eval_col = "__eval_col_" + column.replace(".", "__").replace("`", "_")
+            self.spark_df = self.spark_df.withColumn(eval_col, col(column))
+
             if result_format is None:
                 result_format = self.default_expectation_args["result_format"]
 
@@ -94,10 +106,10 @@ class MetaSparkDFDataset(Dataset):
             else:
                 unexpected_count_limit = result_format["partial_unexpected_count"]
 
-            col_df = self.spark_df.select(column)  # pyspark.sql.DataFrame
+            col_df = self.spark_df.select(col(eval_col))  # pyspark.sql.DataFrame
 
             # a couple of tests indicate that caching here helps performance
-            col_df.cache()
+            col_df.persist()
             element_count = self.get_row_count()
 
             # FIXME temporary fix for missing/ignored value
@@ -107,7 +119,7 @@ class MetaSparkDFDataset(Dataset):
             ]:
                 col_df = col_df.filter(col_df[0].isNotNull())
                 # these nonnull_counts are cached by SparkDFDataset
-                nonnull_count = self.get_column_nonnull_count(column)
+                nonnull_count = self.get_column_nonnull_count(eval_col)
             else:
                 nonnull_count = element_count
 
@@ -117,6 +129,7 @@ class MetaSparkDFDataset(Dataset):
             success_count = success_df.filter("__success = True").count()
 
             unexpected_count = nonnull_count - success_count
+
             if unexpected_count == 0:
                 # save some computation time if no unexpected items
                 maybe_limited_unexpected_list = []
@@ -127,7 +140,7 @@ class MetaSparkDFDataset(Dataset):
                 if unexpected_count_limit:
                     unexpected_df = unexpected_df.limit(unexpected_count_limit)
                 maybe_limited_unexpected_list = [
-                    row[column] for row in unexpected_df.collect()
+                    row[eval_col] for row in unexpected_df.collect()
                 ]
 
                 if "output_strftime_format" in kwargs:
@@ -209,8 +222,16 @@ class MetaSparkDFDataset(Dataset):
             ignore_row_if="both_values_are_missing",
             result_format=None,
             *args,
-            **kwargs
+            **kwargs,
         ):
+            # Rename column so we only have to handle dot notation here
+            eval_col_A = "__eval_col_A_" + column_A.replace(".", "__").replace("`", "_")
+            eval_col_B = "__eval_col_B_" + column_B.replace(".", "__").replace("`", "_")
+
+            self.spark_df = self.spark_df.withColumn(
+                eval_col_A, col(column_A)
+            ).withColumn(eval_col_B, col(column_B))
+
             if result_format is None:
                 result_format = self.default_expectation_args["result_format"]
 
@@ -224,7 +245,7 @@ class MetaSparkDFDataset(Dataset):
             else:
                 unexpected_count_limit = result_format["partial_unexpected_count"]
 
-            cols_df = self.spark_df.select(column_A, column_B).withColumn(
+            cols_df = self.spark_df.select(eval_col_A, eval_col_B).withColumn(
                 "__row", monotonically_increasing_id()
             )  # pyspark.sql.DataFrame
 
@@ -235,26 +256,26 @@ class MetaSparkDFDataset(Dataset):
             if ignore_row_if == "both_values_are_missing":
                 boolean_mapped_null_values = cols_df.selectExpr(
                     "`__row`",
-                    "`{0}` AS `A_{0}`".format(column_A),
-                    "`{0}` AS `B_{0}`".format(column_B),
-                    "ISNULL(`{0}`) AND ISNULL(`{1}`) AS `__null_val`".format(
-                        column_A, column_B
+                    "`{0}` AS `A_{0}`".format(eval_col_A),
+                    "`{0}` AS `B_{0}`".format(eval_col_B),
+                    "ISNULL(`{}`) AND ISNULL(`{}`) AS `__null_val`".format(
+                        eval_col_A, eval_col_B
                     ),
                 )
             elif ignore_row_if == "either_value_is_missing":
                 boolean_mapped_null_values = cols_df.selectExpr(
                     "`__row`",
-                    "`{0}` AS `A_{0}`".format(column_A),
-                    "`{0}` AS `B_{0}`".format(column_B),
-                    "ISNULL(`{0}`) OR ISNULL(`{1}`) AS `__null_val`".format(
-                        column_A, column_B
+                    "`{0}` AS `A_{0}`".format(eval_col_A),
+                    "`{0}` AS `B_{0}`".format(eval_col_B),
+                    "ISNULL(`{}`) OR ISNULL(`{}`) AS `__null_val`".format(
+                        eval_col_A, eval_col_B
                     ),
                 )
             elif ignore_row_if == "never":
                 boolean_mapped_null_values = cols_df.selectExpr(
                     "`__row`",
-                    "`{0}` AS `A_{0}`".format(column_A),
-                    "`{0}` AS `B_{0}`".format(column_B),
+                    "`{0}` AS `A_{0}`".format(eval_col_A),
+                    "`{0}` AS `B_{0}`".format(eval_col_B),
                     lit(False).alias("__null_val"),
                 )
             else:
@@ -267,8 +288,8 @@ class MetaSparkDFDataset(Dataset):
             nonnull_df = boolean_mapped_null_values.filter("__null_val = False")
             nonnull_count = nonnull_df.count()
 
-            col_A_df = nonnull_df.select("__row", "`A_{0}`".format(column_A))
-            col_B_df = nonnull_df.select("__row", "`B_{0}`".format(column_B))
+            col_A_df = nonnull_df.select("__row", "`A_{}`".format(eval_col_A))
+            col_B_df = nonnull_df.select("__row", "`B_{}`".format(eval_col_B))
 
             success_df = func(self, col_A_df, col_B_df, *args, **kwargs)
             success_count = success_df.filter("__success = True").count()
@@ -284,7 +305,7 @@ class MetaSparkDFDataset(Dataset):
                 if unexpected_count_limit:
                     unexpected_df = unexpected_df.limit(unexpected_count_limit)
                 maybe_limited_unexpected_list = [
-                    (row["A_{0}".format(column_A)], row["B_{0}".format(column_B)])
+                    (row["A_{}".format(eval_col_A)], row["B_{}".format(eval_col_B)],)
                     for row in unexpected_df.collect()
                 ]
 
@@ -366,8 +387,14 @@ class MetaSparkDFDataset(Dataset):
             ignore_row_if="all_values_are_missing",
             result_format=None,
             *args,
-            **kwargs
+            **kwargs,
         ):
+            # Rename column so we only have to handle dot notation here
+            eval_cols = []
+            for col_name in column_list:
+                eval_col = "__eval_col_" + col_name.replace(".", "__").replace("`", "_")
+                eval_cols.append(eval_col)
+                self.spark_df = self.spark_df.withColumn(eval_col, col(col_name))
             if result_format is None:
                 result_format = self.default_expectation_args["result_format"]
 
@@ -381,7 +408,7 @@ class MetaSparkDFDataset(Dataset):
             else:
                 unexpected_count_limit = result_format["partial_unexpected_count"]
 
-            temp_df = self.spark_df.select(*column_list)  # pyspark.sql.DataFrame
+            temp_df = self.spark_df.select(*eval_cols)  # pyspark.sql.DataFrame
 
             # a couple of tests indicate that caching here helps performance
             temp_df.cache()
@@ -390,24 +417,24 @@ class MetaSparkDFDataset(Dataset):
             if ignore_row_if == "all_values_are_missing":
                 boolean_mapped_skip_values = temp_df.select(
                     [
-                        *column_list,
+                        *eval_cols,
                         reduce(
-                            lambda a, b: a & b, [col(c).isNull() for c in column_list]
+                            lambda a, b: a & b, [col(c).isNull() for c in eval_cols]
                         ).alias("__null_val"),
                     ]
                 )
             elif ignore_row_if == "any_value_is_missing":
                 boolean_mapped_skip_values = temp_df.select(
                     [
-                        *column_list,
+                        *eval_cols,
                         reduce(
-                            lambda a, b: a | b, [col(c).isNull() for c in column_list]
+                            lambda a, b: a | b, [col(c).isNull() for c in eval_cols]
                         ).alias("__null_val"),
                     ]
                 )
             elif ignore_row_if == "never":
                 boolean_mapped_skip_values = temp_df.select(
-                    [*column_list, lit(False).alias("__null_val")]
+                    [*eval_cols, lit(False).alias("__null_val")]
                 )
             else:
                 raise ValueError("Unknown value of ignore_row_if: %s", (ignore_row_if,))
@@ -415,7 +442,7 @@ class MetaSparkDFDataset(Dataset):
             nonnull_df = boolean_mapped_skip_values.filter("__null_val = False")
             nonnull_count = nonnull_df.count()
 
-            cols_df = nonnull_df.select(*column_list)
+            cols_df = nonnull_df.select(*eval_cols)
 
             success_df = func(self, cols_df, *args, **kwargs)
             success_count = success_df.filter("__success = True").count()
@@ -430,7 +457,10 @@ class MetaSparkDFDataset(Dataset):
                 if unexpected_count_limit:
                     unexpected_df = unexpected_df.limit(unexpected_count_limit)
                 maybe_limited_unexpected_list = [
-                    OrderedDict((c, row[c]) for c in column_list)
+                    OrderedDict(
+                        (col_name, row[eval_col_name])
+                        for (col_name, eval_col_name) in zip(column_list, eval_cols)
+                    )
                     for row in unexpected_df.collect()
                 ]
 
@@ -488,7 +518,75 @@ class MetaSparkDFDataset(Dataset):
 
 class SparkDFDataset(MetaSparkDFDataset):
     """
-    This class holds an attribute `spark_df` which is a spark.sql.DataFrame.
+This class holds an attribute `spark_df` which is a spark.sql.DataFrame.
+
+--ge-feature-maturity-info--
+
+    id: validation_engine_pyspark_self_managed
+    title: Validation Engine - pyspark - Self-Managed
+    icon:
+    short_description: Use Spark DataFrame to validate data
+    description: Use Spark DataFrame to validate data
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/creating_batches/how_to_load_a_spark_dataframe_as_a_batch.html
+    maturity: Production
+    maturity_details:
+        api_stability: Stable
+        implementation_completeness: Moderate
+        unit_test_coverage: Complete
+        integration_infrastructure_test_coverage: N/A -> see relevant Datasource evaluation
+        documentation_completeness: Complete
+        bug_risk: Low/Moderate
+        expectation_completeness: Moderate
+
+    id: validation_engine_databricks
+    title: Validation Engine - Databricks
+    icon:
+    short_description: Use Spark DataFrame in a Databricks cluster to validate data
+    description: Use Spark DataFrame in a Databricks cluster to validate data
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/creating_batches/how_to_load_a_spark_dataframe_as_a_batch.html
+    maturity: Beta
+    maturity_details:
+        api_stability: Stable
+        implementation_completeness: Low (dbfs-specific handling)
+        unit_test_coverage: N/A -> implementation not different
+        integration_infrastructure_test_coverage: Minimal (we've tested a bit, know others have used it)
+        documentation_completeness: Moderate (need docs on managing project configuration via dbfs/etc.)
+        bug_risk: Low/Moderate
+        expectation_completeness: Moderate
+
+    id: validation_engine_emr_spark
+    title: Validation Engine - EMR - Spark
+    icon:
+    short_description: Use Spark DataFrame in an EMR cluster to validate data
+    description: Use Spark DataFrame in an EMR cluster to validate data
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/creating_batches/how_to_load_a_spark_dataframe_as_a_batch.html
+    maturity: Experimental
+    maturity_details:
+        api_stability: Stable
+        implementation_completeness: Low (need to provide guidance on "known good" paths, and we know there are many "knobs" to tune that we have not explored/tested)
+        unit_test_coverage: N/A -> implementation not different
+        integration_infrastructure_test_coverage: Unknown
+        documentation_completeness: Low (must install specific/latest version but do not have docs to that effect or of known useful paths)
+        bug_risk: Low/Moderate
+        expectation_completeness: Moderate
+
+    id: validation_engine_spark_other
+    title: Validation Engine - Spark - Other
+    icon:
+    short_description: Use Spark DataFrame to validate data
+    description: Use Spark DataFrame to validate data
+    how_to_guide_url: https://docs.greatexpectations.io/en/latest/how_to_guides/creating_batches/how_to_load_a_spark_dataframe_as_a_batch.html
+    maturity: Experimental
+    maturity_details:
+        api_stability: Stable
+        implementation_completeness: Other (we haven't tested possibility, known glue deployment)
+        unit_test_coverage: N/A -> implementation not different
+        integration_infrastructure_test_coverage: Unknown
+        documentation_completeness: Low (must install specific/latest version but do not have docs to that effect or of known useful paths)
+        bug_risk: Low/Moderate
+        expectation_completeness: Moderate
+
+--ge-feature-maturity-info--
     """
 
     @classmethod
@@ -504,7 +602,7 @@ class SparkDFDataset(MetaSparkDFDataset):
         self._persist = kwargs.pop("persist", True)
         if self._persist:
             self.spark_df.persist()
-        super(SparkDFDataset, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def head(self, n=5):
         """Returns a *PandasDataset* with the first *n* rows of the given Dataset"""
@@ -1038,13 +1136,17 @@ class SparkDFDataset(MetaSparkDFDataset):
         catch_exceptions=None,
         meta=None,
     ):
+        # Rename column so we only have to handle dot notation here
+        eval_col = "__eval_col_" + column.replace(".", "__").replace("`", "_")
+        self.spark_df = self.spark_df.withColumn(eval_col, col(column))
         if mostly is not None:
             raise ValueError(
                 "SparkDFDataset does not support column map semantics for column types"
             )
 
         try:
-            col_data = [f for f in self.spark_df.schema.fields if f.name == column][0]
+            col_df = self.spark_df.select(eval_col)
+            col_data = [f for f in col_df.schema.fields if f.name == eval_col][0]
             col_type = type(col_data.dataType)
         except IndexError:
             raise ValueError("Unrecognized column: %s" % column)
@@ -1064,24 +1166,29 @@ class SparkDFDataset(MetaSparkDFDataset):
             raise ValueError("Unrecognized spark type: %s" % type_)
 
     @DocInherit
-    @DataAsset.expectation(["column", "type_", "mostly"])
+    @DataAsset.expectation(["column", "type_list", "mostly"])
     def expect_column_values_to_be_in_type_list(
         self,
         column,
-        type_list,
+        type_list: List[str],
         mostly=None,
         result_format=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
     ):
+        # Rename column so we only have to handle dot notation here
+        eval_col = "__eval_col_" + column.replace(".", "__").replace("`", "_")
+        self.spark_df = self.spark_df.withColumn(eval_col, col(column))
+
         if mostly is not None:
             raise ValueError(
                 "SparkDFDataset does not support column map semantics for column types"
             )
 
         try:
-            col_data = [f for f in self.spark_df.schema.fields if f.name == column][0]
+            col_df = self.spark_df.select(eval_col)
+            col_data = [f for f in col_df.schema.fields if f.name == eval_col][0]
             col_type = type(col_data.dataType)
         except IndexError:
             raise ValueError("Unrecognized column: %s" % column)
@@ -1203,8 +1310,8 @@ class SparkDFDataset(MetaSparkDFDataset):
             _udf = udf(parse, sparktypes.TimestampType())
             # Create new columns for comparison without replacing original values.
             (timestamp_column_A, timestamp_column_B) = (
-                "__ts_{0}".format(column_A_name),
-                "__ts_{0}".format(column_B_name),
+                "__ts_{}".format(column_A_name),
+                "__ts_{}".format(column_B_name),
             )
             temp_column_A = column_A.withColumn(timestamp_column_A, _udf(column_A_name))
             temp_column_B = column_B.withColumn(timestamp_column_B, _udf(column_B_name))
@@ -1231,16 +1338,82 @@ class SparkDFDataset(MetaSparkDFDataset):
             )
 
     @DocInherit
-    @MetaSparkDFDataset.multicolumn_map_expectation
+    @MetaSparkDFDataset.column_pair_map_expectation
+    def expect_column_pair_values_to_be_in_set(
+        self,
+        column_A,
+        column_B,
+        value_pairs_set,  # List[List]
+        ignore_row_if="both_values_are_missing",
+        result_format=None,
+        include_config=True,
+        catch_exceptions=None,
+        meta=None,
+    ):
+        column_A_name = column_A.schema.names[1]
+        column_B_name = column_B.schema.names[1]
+
+        join_df = column_A.join(
+            column_B, column_A["__row"] == column_B["__row"], how="inner"
+        )
+
+        join_df = join_df.withColumn(
+            "combine_AB", array(col(column_A_name), col(column_B_name))
+        )
+
+        value_set_df = (
+            SQLContext(self.spark_df._sc)
+            .createDataFrame(value_pairs_set, ["col_A", "col_B"])
+            .select(array("col_A", "col_B").alias("set_AB"))
+        )
+
+        return join_df.join(
+            value_set_df, join_df["combine_AB"] == value_set_df["set_AB"], "left"
+        ).withColumn(
+            "__success", when(col("set_AB").isNull(), lit(False)).otherwise(lit(True))
+        )
+
     def expect_multicolumn_values_to_be_unique(
         self,
         column_list,  # pyspark.sql.DataFrame
+        mostly=None,
         ignore_row_if="all_values_are_missing",
         result_format=None,
         include_config=True,
         catch_exceptions=None,
         meta=None,
     ):
+        deprecation_warning = (
+            "expect_multicolumn_values_to_be_unique is being deprecated. Please use "
+            "expect_select_column_values_to_be_unique_within_record instead."
+        )
+        warnings.warn(
+            deprecation_warning, DeprecationWarning,
+        )
+
+        return self.expect_select_column_values_to_be_unique_within_record(
+            column_list=column_list,
+            mostly=mostly,
+            ignore_row_if=ignore_row_if,
+            result_format=result_format,
+            include_config=include_config,
+            catch_exceptions=catch_exceptions,
+            meta=meta,
+        )
+
+    @DocInherit
+    @MetaSparkDFDataset.multicolumn_map_expectation
+    def expect_select_column_values_to_be_unique_within_record(
+        self,
+        column_list,  # pyspark.sql.DataFrame
+        mostly=None,
+        ignore_row_if="all_values_are_missing",
+        result_format=None,
+        include_config=True,
+        catch_exceptions=None,
+        meta=None,
+    ):
+        # Might want to throw an exception if only 1 column is passed
         column_names = column_list.schema.names[:]
         conditions = []
         for i in range(0, len(column_names) - 1):
@@ -1252,3 +1425,157 @@ class SparkDFDataset(MetaSparkDFDataset):
         return column_list.withColumn(
             "__success", reduce(lambda a, b: a & b, conditions)
         )
+
+    @DocInherit
+    @MetaSparkDFDataset.column_map_expectation
+    def expect_column_values_to_be_increasing(
+        self,
+        column,  # pyspark.sql.DataFrame
+        strictly=False,
+        mostly=None,
+        parse_strings_as_datetimes=None,
+        output_strftime_format=None,
+        result_format=None,
+        include_config=True,
+        catch_exceptions=None,
+        meta=None,
+    ):
+        # string column name
+        column_name = column.schema.names[0]
+        # check if column is any type that could have na (numeric types)
+        na_types = [
+            isinstance(column.schema[column_name].dataType, typ)
+            for typ in [
+                sparktypes.LongType,
+                sparktypes.DoubleType,
+                sparktypes.IntegerType,
+            ]
+        ]
+
+        # if column is any type that could have NA values, remove them (not filtered by .isNotNull())
+        if any(na_types):
+            column = column.filter(~isnan(column[0]))
+
+        if parse_strings_as_datetimes:
+            # convert column to timestamp format
+            column = self._apply_dateutil_parse(column)
+            # create constant column to order by in window function to preserve order of original df
+            column = column.withColumn("constant", lit("constant")).withColumn(
+                "lag", lag(column[0]).over(Window.orderBy(col("constant")))
+            )
+
+            column = column.withColumn("diff", datediff(col(column_name), col("lag")))
+
+        else:
+            column = (
+                column.withColumn("constant", lit("constant"))
+                .withColumn("lag", lag(column[0]).over(Window.orderBy(col("constant"))))
+                .withColumn("diff", column[0] - col("lag"))
+            )
+
+        # replace lag first row null with 1 so that it is not flagged as fail
+        column = column.withColumn(
+            "diff", when(col("diff").isNull(), 1).otherwise(col("diff"))
+        )
+
+        if strictly:
+            return column.withColumn(
+                "__success", when(col("diff") >= 1, lit(True)).otherwise(lit(False))
+            )
+
+        else:
+            return column.withColumn(
+                "__success", when(col("diff") >= 0, lit(True)).otherwise(lit(False))
+            )
+
+    @DocInherit
+    @MetaSparkDFDataset.column_map_expectation
+    def expect_column_values_to_be_decreasing(
+        self,
+        column,  # pyspark.sql.DataFrame
+        strictly=False,
+        mostly=None,
+        parse_strings_as_datetimes=None,
+        output_strftime_format=None,
+        result_format=None,
+        include_config=True,
+        catch_exceptions=None,
+        meta=None,
+    ):
+        # string column name
+        column_name = column.schema.names[0]
+        # check if column is any type that could have na (numeric types)
+        na_types = [
+            isinstance(column.schema[column_name].dataType, typ)
+            for typ in [
+                sparktypes.LongType,
+                sparktypes.DoubleType,
+                sparktypes.IntegerType,
+            ]
+        ]
+
+        # if column is any type that could have NA values, remove them (not filtered by .isNotNull())
+        if any(na_types):
+            column = column.filter(~isnan(column[0]))
+
+        if parse_strings_as_datetimes:
+            # convert column to timestamp format
+            column = self._apply_dateutil_parse(column)
+            # create constant column to order by in window function to preserve order of original df
+            column = column.withColumn("constant", lit("constant")).withColumn(
+                "lag", lag(column[0]).over(Window.orderBy(col("constant")))
+            )
+
+            column = column.withColumn("diff", datediff(col(column_name), col("lag")))
+
+        else:
+            column = (
+                column.withColumn("constant", lit("constant"))
+                .withColumn("lag", lag(column[0]).over(Window.orderBy(col("constant"))))
+                .withColumn("diff", column[0] - col("lag"))
+            )
+
+        # replace lag first row null with -1 so that it is not flagged as fail
+        column = column.withColumn(
+            "diff", when(col("diff").isNull(), -1).otherwise(col("diff"))
+        )
+
+        if strictly:
+            return column.withColumn(
+                "__success", when(col("diff") <= -1, lit(True)).otherwise(lit(False))
+            )
+
+        else:
+            return column.withColumn(
+                "__success", when(col("diff") <= 0, lit(True)).otherwise(lit(False))
+            )
+
+    @DocInherit
+    @MetaSparkDFDataset.multicolumn_map_expectation
+    def expect_multicolumn_sum_to_equal(
+        self,
+        column_list,
+        sum_total,
+        result_format=None,
+        include_config=True,
+        catch_exceptions=None,
+        meta=None,
+    ):
+        """ Multi-Column Map Expectation
+
+        Expects that sum of all rows for a set of columns is equal to a specific value
+
+        Args:
+            column_list (List[str]): \
+                Set of columns to be checked
+            sum_total (int): \
+                expected sum of columns
+        """
+        expression = "+".join(
+            ["COALESCE({}, 0)".format(col) for col in column_list.columns]
+        )
+        column_list = column_list.withColumn("actual_total", expr(expression))
+        return column_list.withColumn(
+            "__success",
+            when(col("actual_total") == sum_total, lit(True)).otherwise(lit(False)),
+        )
