@@ -29,7 +29,7 @@ FALSEY_YAML_STRINGS = [
 ]
 
 
-class SiteBuilder(object):
+class SiteBuilder:
     """SiteBuilder builds data documentation for the project defined by a
     DataContext.
 
@@ -276,7 +276,7 @@ class SiteBuilder(object):
         (ExpectationSuiteIdentifier,
                             ValidationResultIdentifier). If specified,
                             rebuild HTML(or other views the data docs
-                            site renders) only forthe resources in this list.
+                            site renders) only for the resources in this list.
                             This supports incremental build of data docs sites
                             (e.g., when a new validation result is created)
                             and avoids full rebuild.
@@ -302,7 +302,7 @@ class SiteBuilder(object):
 
         :param resource_identifier: ExpectationSuiteIdentifier,
         ValidationResultIdentifier or any other type's identifier. The
-        argument is optional - whennot supplied, the method returns the URL of
+        argument is optional - when not supplied, the method returns the URL of
         the index page.
         :return: URL (string)
         """
@@ -312,7 +312,7 @@ class SiteBuilder(object):
         )
 
 
-class DefaultSiteSectionBuilder(object):
+class DefaultSiteSectionBuilder:
     def __init__(
         self,
         name,
@@ -446,6 +446,13 @@ class DefaultSiteSectionBuilder(object):
                     data_context_id=self.data_context_id,
                     show_how_to_buttons=self.show_how_to_buttons,
                 )
+
+                self.target_store.set(
+                    SiteSectionIdentifier(
+                        site_section_name=self.name, resource_identifier=resource_key,
+                    ),
+                    viewable_content,
+                )
             except Exception as e:
                 exception_message = f"""\
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
@@ -459,15 +466,8 @@ diagnose and repair the underlying issue.  Detailed information follows:
                 )
                 logger.error(exception_message, e, exc_info=True)
 
-            self.target_store.set(
-                SiteSectionIdentifier(
-                    site_section_name=self.name, resource_identifier=resource_key,
-                ),
-                viewable_content,
-            )
 
-
-class DefaultSiteIndexBuilder(object):
+class DefaultSiteIndexBuilder:
     def __init__(
         self,
         name,
@@ -651,7 +651,7 @@ class DefaultSiteIndexBuilder(object):
         validation_playground = CallToActionButton(
             "How to Validate Data",
             # TODO update this link to a proper tutorial
-            "https://docs.greatexpectations.io/en/latest/how_to_guides/validation.html",
+            "https://docs.greatexpectations.io/en/latest/guides/how_to_guides/validation.html",
         )
         customize_data_docs = CallToActionButton(
             "How to Customize Data Docs",
@@ -809,7 +809,7 @@ class DefaultSiteIndexBuilder(object):
                         batch_kwargs=batch_kwargs,
                     )
                 except Exception:
-                    error_msg = "Profiling result not found: {0:s} - skipping".format(
+                    error_msg = "Profiling result not found: {:s} - skipping".format(
                         str(profiling_result_key.to_tuple())
                     )
                     logger.warning(error_msg)
@@ -863,7 +863,7 @@ class DefaultSiteIndexBuilder(object):
                         batch_kwargs=batch_kwargs,
                     )
                 except Exception:
-                    error_msg = "Validation result not found: {0:s} - skipping".format(
+                    error_msg = "Validation result not found: {:s} - skipping".format(
                         str(validation_result_key.to_tuple())
                     )
                     logger.warning(error_msg)
@@ -890,7 +890,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
         return (self.target_store.write_index_page(viewable_content), index_links_dict)
 
 
-class CallToActionButton(object):
+class CallToActionButton:
     def __init__(self, title, link):
         self.title = title
         self.link = link
